import customtkinter as ctk
import requests
from tkinter import messagebox

def category_frame(parent, switch_func, API_URL, access_token):
    frame = ctk.CTkFrame(parent)

    ctk.CTkLabel(frame, text="Category Management", font=("Helvetica", 18, "bold")).pack(pady=10)

    ctk.CTkLabel(frame, text="Category Name:").pack(pady=5)
    entry_name = ctk.CTkEntry(frame)
    entry_name.pack(pady=5)

    ctk.CTkLabel(frame, text="Category ID (for update/delete):").pack(pady=5)
    entry_id = ctk.CTkEntry(frame)
    entry_id.pack(pady=5)

    headers = {"Authorization": f"Bearer {access_token}"} if access_token else {}

    def create_category():
        name = entry_name.get().strip()
        if not name:
            messagebox.showwarning("Input Error", "Category name is required!")
            return

        try:
            response = requests.post(f"{API_URL}/category", data={"name": name}, headers=headers)
            if response.status_code == 200:
                messagebox.showinfo("Success", f"Category '{name}' created successfully!")
                entry_name.delete(0, 'end')
            else:
                messagebox.showerror("Error", response.json().get("detail", "Failed to create category"))
        except requests.exceptions.RequestException as e:
            messagebox.showerror("Error", f"Failed to connect to server: {e}")

    def list_categories():
        try:
            response = requests.get(f"{API_URL}/category", headers=headers)
            if response.status_code == 200:
                categories = response.json()
                if categories:
                    category_list = "\n".join([f"{cat['id']}: {cat['name']}" for cat in categories])
                    messagebox.showinfo("Categories", category_list)
                else:
                    messagebox.showinfo("Categories", "No categories available.")
            else:
                messagebox.showerror("Error", "Failed to fetch categories")
        except requests.exceptions.RequestException as e:
            messagebox.showerror("Error", f"Failed to connect to server: {e}")

    def update_category():
        category_id = entry_id.get().strip()
        name = entry_name.get().strip()
        if not category_id.isdigit():
            messagebox.showwarning("Input Error", "Enter a valid Category ID!")
            return
        if not name:
            messagebox.showwarning("Input Error", "Category name is required for update!")
            return

        try:
            response = requests.put(f"{API_URL}/category/{category_id}", data={"name": name}, headers=headers)
            if response.status_code == 200:
                messagebox.showinfo("Success", "Category updated successfully!")
                entry_id.delete(0, 'end')
                entry_name.delete(0, 'end')
            else:
                messagebox.showerror("Error", response.json().get("detail", "Failed to update category"))
        except requests.exceptions.RequestException as e:
            messagebox.showerror("Error", f"Failed to connect to server: {e}")

    def delete_category():
        category_id = entry_id.get().strip()
        if not category_id.isdigit():
            messagebox.showwarning("Input Error", "Enter a valid Category ID!")
            return

        try:
            response = requests.delete(f"{API_URL}/category/{category_id}", headers=headers)
            if response.status_code == 200:
                messagebox.showinfo("Success", "Category deleted successfully!")
                entry_id.delete(0, 'end')
            else:
                messagebox.showerror("Error", response.json().get("detail", "Failed to delete category"))
        except requests.exceptions.RequestException as e:
            messagebox.showerror("Error", f"Failed to connect to server: {e}")

    ctk.CTkButton(frame, text="Create Category", command=create_category).pack(pady=5)
    ctk.CTkButton(frame, text="List Categories", command=list_categories).pack(pady=5)
    ctk.CTkButton(frame, text="Update Category", command=update_category).pack(pady=5)
    ctk.CTkButton(frame, text="Delete Category", command=delete_category).pack(pady=5)
    ctk.CTkButton(frame, text="Back", command=lambda: switch_func("")).pack(pady=5)

    return frame
