import customtkinter as ctk
from tkinter import messagebox
import requests

def register_frame(parent, switch_func, API_URL):
    frame = ctk.CTkFrame(parent)

    def register():
        username = entry_username.get()
        email = entry_email.get()
        phone_number = entry_phone.get()
        password = entry_password.get()
        confirm_password = entry_confirm_password.get()

        if not username or not email or not phone_number or not password or not confirm_password:
            messagebox.showwarning("Input Error", "All fields are required!")
            return

        if password != confirm_password:
            messagebox.showerror("Password Error", "Passwords do not match!")
            return

        response = requests.post(
            f"{API_URL}/auth/signup",
            json={"username": username, "email": email, "phone_number": phone_number, "password": password},
        )

        try:
            response_data = response.json()
            if response.status_code == 200:
                messagebox.showinfo("Registration Successful", f"Welcome, {username}!")
                switch_func("login")
            else:
                messagebox.showerror("Registration Failed", response_data.get("detail", "Unknown error"))
        except requests.exceptions.JSONDecodeError:
            messagebox.showerror("Registration Failed", "Server returned an invalid response.")

    ctk.CTkLabel(frame, text="Register", font=("Helvetica", 18, "bold")).pack(pady=10)

    ctk.CTkLabel(frame, text="Username:").pack(pady=5)
    entry_username = ctk.CTkEntry(frame)
    entry_username.pack(pady=5)

    ctk.CTkLabel(frame, text="Email:").pack(pady=5)
    entry_email = ctk.CTkEntry(frame)
    entry_email.pack(pady=5)

    ctk.CTkLabel(frame, text="Phone Number:").pack(pady=5)
    entry_phone = ctk.CTkEntry(frame)
    entry_phone.pack(pady=5)

    ctk.CTkLabel(frame, text="Password:").pack(pady=5)
    entry_password = ctk.CTkEntry(frame, show="*")
    entry_password.pack(pady=5)

    ctk.CTkLabel(frame, text="Confirm Password:").pack(pady=5)
    entry_confirm_password = ctk.CTkEntry(frame, show="*")
    entry_confirm_password.pack(pady=5)

    ctk.CTkButton(frame, text="Register", command=register).pack(pady=15)

    ctk.CTkButton(
        frame,
        text="Already have an account? Login",
        command=lambda: switch_func("login"),
    ).pack()

    return frame
