import customtkinter as ctk
import requests
from tkinter import messagebox
from PIL import Image, ImageTk
import io

def view_shop_frame(parent, switch_func, API_URL, token):
    frame = ctk.CTkFrame(parent)

    # Title
    title_label = ctk.CTkLabel(frame, text="Your Shop", font=("Helvetica", 18, "bold"))
    title_label.pack(pady=10)

    # Shop Details
    shop_name_label = ctk.CTkLabel(frame, text="Shop Name: ", font=("Helvetica", 14, "bold"))
    shop_name_label.pack(pady=5)
    
    shop_description_label = ctk.CTkLabel(frame, text="Description: ", font=("Helvetica", 12))
    shop_description_label.pack(pady=5)

    shop_image_label = ctk.CTkLabel(frame, text="")  # Placeholder for shop image
    shop_image_label.pack(pady=10)

    # Product List Section
    product_list_frame = ctk.CTkFrame(frame)
    product_list_frame.pack(fill="both", expand=True, padx=10, pady=10)

    def fetch_shop_data():
        """ Fetch the shop created by the logged-in user """
        headers = {"Authorization": f"Bearer {token}"}
        try:
            response = requests.get(f"{API_URL}/shops/my-shop", headers=headers)  # Adjust the endpoint as needed
            if response.status_code == 200:
                shop_data = response.json()
                shop_name_label.configure(text=f"Shop Name: {shop_data['name']}")
                shop_description_label.configure(text=f"Description: {shop_data.get('description', 'No description')}")

                # Load and display shop image if available
                if "image_url" in shop_data and shop_data["image_url"]:
                    try:
                        image_response = requests.get(shop_data["image_url"])
                        image = Image.open(io.BytesIO(image_response.content))
                        image = image.resize((150, 150))
                        img_tk = ImageTk.PhotoImage(image)

                        shop_image_label.configure(image=img_tk, text="")
                        shop_image_label.image = img_tk
                    except Exception:
                        pass
                
                fetch_products(shop_data["id"])  # Fetch products for this shop
            else:
                messagebox.showerror("Error", "Failed to fetch shop details.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    def fetch_products(shop_id):
        """ Fetch products that belong to the user's shop """
        headers = {"Authorization": f"Bearer {token}"}
        try:
            response = requests.get(f"{API_URL}/products?shop_id={shop_id}", headers=headers)
            if response.status_code == 200:
                products = response.json()
                display_products(products)
            else:
                messagebox.showerror("Error", "Failed to fetch products.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    def display_products(products):
        """ Display the list of products in the shop """
        for widget in product_list_frame.winfo_children():
            widget.destroy()

        if not products:
            ctk.CTkLabel(product_list_frame, text="No products found.", font=("Helvetica", 12)).pack(pady=10)
            return

        for product in products:
            product_frame = ctk.CTkFrame(product_list_frame)
            product_frame.pack(fill="x", padx=5, pady=5)

            # Product Image
            img_label = ctk.CTkLabel(product_frame, text="")  # Placeholder
            img_label.pack(side="left", padx=5)

            # Load and display product image
            if "images" in product and product["images"]:
                image_url = product["images"][0]["image_url"]
                try:
                    image_response = requests.get(image_url)
                    image = Image.open(io.BytesIO(image_response.content))
                    image = image.resize((50, 50))
                    img_tk = ImageTk.PhotoImage(image)

                    img_label.configure(image=img_tk, text="")
                    img_label.image = img_tk
                except Exception:
                    pass

            # Product Details
            details_frame = ctk.CTkFrame(product_frame)
            details_frame.pack(side="left", fill="x", expand=True, padx=10)

            ctk.CTkLabel(details_frame, text=product["name"], font=("Helvetica", 12, "bold")).pack(anchor="w")
            ctk.CTkLabel(details_frame, text=f"Price: ${product['price']:.2f}", font=("Helvetica", 12)).pack(anchor="w")

    # Refresh Data Button
    refresh_button = ctk.CTkButton(frame, text="Refresh", command=fetch_shop_data)
    refresh_button.pack(pady=10)

    # Back Button
    back_button = ctk.CTkButton(frame, text="Back", command=lambda: switch_func("login"))
    back_button.pack(pady=10)

    # Fetch shop data on load
    fetch_shop_data()

    return frame
